# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .conversation_token_purpose import ConversationTokenPurpose
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ConversationTokenDbModel(UncheckedBaseModel):
    agent_id: str
    conversation_token: str
    expiration_time_unix_secs: typing.Optional[int] = None
    purpose: typing.Optional[ConversationTokenPurpose] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
